==> hibiscus.js-1.2.1.tgz: package/carousel/carousel.component.js <==
import { Component, ChangeDetectionStrategy, QueryList, ContentChildren, Input, Output, EventEmitter, HostListener, Renderer2, ViewChildren } from '@angular/core';
import { SlideDirective } from './slide.directive';
import { animation, animationTimeout } from '../utils/animation-utils';
import { HiNGConfig } from '../hi.config';
export var CarouselDirection;
(function (CarouselDirection) {
    CarouselDirection[CarouselDirection["NEXT"] = 0] = "NEXT";
    CarouselDirection[CarouselDirection["PREV"] = 1] = "PREV";
})(CarouselDirection || (CarouselDirection = {}));
var CarouselComponent = /** @class */ (function () {
    function CarouselComponent(renderer, hiNGConfig) {
        this.renderer = renderer;
        this.hiNGConfig = hiNGConfig;
        this.activeSlide = 0;
        this.activeSlideChange = new EventEmitter();
        this.reflowDuration = hiNGConfig.carousel.reflowDuration;
        this.animationDuration = hiNGConfig.carousel.animationDuration;
        this.animate = hiNGConfig.carousel.animate;
        this.interval = hiNGConfig.carousel.interval;
    }
    CarouselComponent.prototype.ngAfterContentInit = function () {
        if (this.interval) {
            this.startInterval();
        }
    };
    CarouselComponent.prototype.selectSlide = function (index) {
        if (this.activeSlide !== index) {
            var direction = index > this.activeSlide ? CarouselDirection.NEXT : CarouselDirection.PREV;
            this.onActiveSlideChange(index, direction);
        }
    };
    CarouselComponent.prototype.selectPrevSlide = function ($event) {
        if (this.activeSlide === 0) {
            this.onActiveSlideChange(this.slides.length - 1, CarouselDirection.PREV);
            return;
        }
        this.onActiveSlideChange(this.activeSlide - 1, CarouselDirection.PREV);
    };
    CarouselComponent.prototype.selectNextSlide = function ($event) {
        if (this.activeSlide === this.slides.length - 1) {
            this.onActiveSlideChange(0, CarouselDirection.NEXT);
            return;
        }
        this.onActiveSlideChange(this.activeSlide + 1, CarouselDirection.NEXT);
    };
    CarouselComponent.prototype.onActiveSlideChange = function (index, carouselDirection) {
        var _this = this;
        if (this.activeSlide === index) {
            return;
        }
        this.slideAnimation(carouselDirection, index)
            .then(function () {
            _this.activeSlide = index;
            _this.activeSlideChange.emit(_this.activeSlide);
        });
    };
    CarouselComponent.prototype.pauseInterval = function () {
        this.stopInterval();
    };
    CarouselComponent.prototype.startInterval = function () {
        var _this = this;
        this.stopInterval();
        if (this.interval) {
            this.intervalId = setInterval(function () { return _this.selectNextSlide(); }, this.interval);
        }
    };
    CarouselComponent.prototype.ngOnDestroy = function () {
        this.stopInterval();
    };
    CarouselComponent.prototype.slideAnimation = function (carouselDirection, index) {
        var _this = this;
        this.stopInterval();
        var slideItems = this.slideItems.toArray();
        var direction = carouselDirection === CarouselDirection.NEXT ? 'left' : 'right';
        var orderDirection = carouselDirection === CarouselDirection.NEXT ? 'next' : 'prev';
        var nextElement = slideItems[index].nativeElement;
        var currentElement = slideItems[this.activeSlide].nativeElement;
        this.renderer.addClass(nextElement, orderDirection);
        return animationTimeout(this.reflowDuration)
            .then(function () {
            _this.renderer.addClass(currentElement, direction);
            _this.renderer.addClass(nextElement, direction);
        })
            .then(function () { return animation(_this.renderer, nextElement, _this.animationDuration); })
            .then(function () {
            _this.renderer.removeClass(nextElement, orderDirection);
            _this.renderer.removeClass(nextElement, direction);
            _this.renderer.removeClass(currentElement, direction);
            _this.startInterval();
        });
    };
    CarouselComponent.prototype.stopInterval = function () {
        if (this.intervalId) {
            clearInterval(this.intervalId);
        }
    };
    CarouselComponent.decorators = [
        { type: Component, args: [{
                    selector: 'hi-carousel',
                    template: "\n    <div class=\"carousel slide\" data-ride=\"carousel\"><ol class=\"carousel-indicators\"><li *ngFor=\"let silde of slides; let $index = index\" [attr.data-slide-to]=\"$index\" (click)=\"selectSlide($index)\" [ngClass]=\"{active: $index == activeSlide}\"></li></ol><div class=\"carousel-inner\" role=\"listbox\"><div class=\"carousel-item\" #slideItem *ngFor=\"let silde of slides; let $index = index\" [ngClass]=\"{active: $index == activeSlide}\"><ng-template [ngTemplateOutlet]=\"silde.templateRef\"></ng-template></div></div><a class=\"carousel-control-prev\" role=\"button\" data-slide=\"prev\" (click)=\"selectPrevSlide()\"><span class=\"carousel-control-prev-icon\" aria-hidden=\"true\"></span> <span class=\"sr-only\">Previous</span> </a><a class=\"carousel-control-next\" role=\"button\" data-slide=\"next\" (click)=\"selectNextSlide()\"><span class=\"carousel-control-next-icon\" aria-hidden=\"true\"></span> <span class=\"sr-only\">Next</span></a></div>\n  ",
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    exportAs: 'carousel'
                },] },
    ];
    /** @nocollapse */
    CarouselComponent.ctorParameters = function () { return [
        { type: Renderer2, },
        { type: HiNGConfig, },
    ]; };
    CarouselComponent.propDecorators = {
        "activeSlide": [{ type: Input },],
        "interval": [{ type: Input },],
        "animate": [{ type: Input },],
        "activeSlideChange": [{ type: Output },],
        "slides": [{ type: ContentChildren, args: [SlideDirective,] },],
        "slideItems": [{ type: ViewChildren, args: ['slideItem',] },],
        "selectPrevSlide": [{ type: HostListener, args: ['keydown.arrowLeft', ['$event'],] },],
        "selectNextSlide": [{ type: HostListener, args: ['keydown.arrowRight', ['$event'],] },],
        "pauseInterval": [{ type: HostListener, args: ['mouseenter', [],] },],
        "startInterval": [{ type: HostListener, args: ['mouseleave', [],] },],
    };
    return CarouselComponent;
}());
export { CarouselComponent };

==> hibiscus.js-1.2.3.tgz: package/carousel/carousel.component.js <==
import { Component, ChangeDetectionStrategy, QueryList, ContentChildren, Input, Output, EventEmitter, HostListener, Renderer2, ViewChildren } from '@angular/core';
import { SlideDirective } from './slide.directive';
import { animation, animationTimeout } from '../utils/animation-utils';
import { HiNGConfig } from '../hi.config';
export var CarouselDirection;
(function (CarouselDirection) {
    CarouselDirection[CarouselDirection["NEXT"] = 0] = "NEXT";
    CarouselDirection[CarouselDirection["PREV"] = 1] = "PREV";
})(CarouselDirection || (CarouselDirection = {}));
var CarouselComponent = (function () {
    function CarouselComponent(renderer, hiNGConfig) {
        this.renderer = renderer;
        this.hiNGConfig = hiNGConfig;
        this.activeSlide = 0;
        this.activeSlideChange = new EventEmitter();
        this.reflowDuration = hiNGConfig.carousel.reflowDuration;
        this.animationDuration = hiNGConfig.carousel.animationDuration;
        this.animate = hiNGConfig.carousel.animate;
        this.interval = hiNGConfig.carousel.interval;
    }
    CarouselComponent.prototype.ngAfterContentInit = function () {
        if (this.interval) {
            this.startInterval();
        }
    };
    CarouselComponent.prototype.selectSlide = function (index) {
        if (this.activeSlide !== index) {
            var direction = index > this.activeSlide ? CarouselDirection.NEXT : CarouselDirection.PREV;
            this.onActiveSlideChange(index, direction);
        }
    };
    CarouselComponent.prototype.selectPrevSlide = function ($event) {
        if (this.activeSlide === 0) {
            this.onActiveSlideChange(this.slides.length - 1, CarouselDirection.PREV);
            return;
        }
        this.onActiveSlideChange(this.activeSlide - 1, CarouselDirection.PREV);
    };
    CarouselComponent.prototype.selectNextSlide = function ($event) {
        if (this.activeSlide === this.slides.length - 1) {
            this.onActiveSlideChange(0, CarouselDirection.NEXT);
            return;
        }
        this.onActiveSlideChange(this.activeSlide + 1, CarouselDirection.NEXT);
    };
    CarouselComponent.prototype.onActiveSlideChange = function (index, carouselDirection) {
        var _this = this;
        if (this.activeSlide === index) {
            return;
        }
        this.slideAnimation(carouselDirection, index)
            .then(function () {
            _this.activeSlide = index;
            _this.activeSlideChange.emit(_this.activeSlide);
        });
    };
    CarouselComponent.prototype.pauseInterval = function () {
        this.stopInterval();
    };
    CarouselComponent.prototype.startInterval = function () {
        var _this = this;
        this.stopInterval();
        if (this.interval) {
            this.intervalId = setInterval(function () { return _this.selectNextSlide(); }, this.interval);
        }
    };
    CarouselComponent.prototype.ngOnDestroy = function () {
        this.stopInterval();
    };
    CarouselComponent.prototype.slideAnimation = function (carouselDirection, index) {
        var _this = this;
        this.stopInterval();
        var slideItems = this.slideItems.toArray();
        var direction = carouselDirection === CarouselDirection.NEXT ? 'left' : 'right';
        var orderDirection = carouselDirection === CarouselDirection.NEXT ? 'next' : 'prev';
        var nextElement = slideItems[index].nativeElement;
        var currentElement = slideItems[this.activeSlide].nativeElement;
        this.renderer.addClass(nextElement, orderDirection);
        return animationTimeout(this.reflowDuration)
            .then(function () {
            _this.renderer.addClass(currentElement, direction);
            _this.renderer.addClass(nextElement, direction);
        })
            .then(function () { return animation(_this.renderer, nextElement, _this.animationDuration); })
            .then(function () {
            _this.renderer.removeClass(nextElement, orderDirection);
            _this.renderer.removeClass(nextElement, direction);
            _this.renderer.removeClass(currentElement, direction);
            _this.startInterval();
        });
    };
    CarouselComponent.prototype.stopInterval = function () {
        if (this.intervalId) {
            clearInterval(this.intervalId);
        }
    };
    CarouselComponent.decorators = [
        { type: Component, args: [{
                    selector: 'hi-carousel',
                    template: "\n    <div class=\"carousel slide\" data-ride=\"carousel\"><ol class=\"carousel-indicators\"><li *ngFor=\"let silde of slides; let $index = index\" [attr.data-slide-to]=\"$index\" (click)=\"selectSlide($index)\" [ngClass]=\"{active: $index == activeSlide}\"></li></ol><div class=\"carousel-inner\" role=\"listbox\"><div class=\"carousel-item\" #slideItem *ngFor=\"let silde of slides; let $index = index\" [ngClass]=\"{active: $index == activeSlide}\"><ng-template [ngTemplateOutlet]=\"silde.templateRef\"></ng-template></div></div><a class=\"carousel-control-prev\" role=\"button\" data-slide=\"prev\" (click)=\"selectPrevSlide()\"><span class=\"carousel-control-prev-icon\" aria-hidden=\"true\"></span> <span class=\"sr-only\">Previous</span> </a><a class=\"carousel-control-next\" role=\"button\" data-slide=\"next\" (click)=\"selectNextSlide()\"><span class=\"carousel-control-next-icon\" aria-hidden=\"true\"></span> <span class=\"sr-only\">Next</span></a></div>\n  ",
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    exportAs: 'carousel'
                },] },
    ];
    CarouselComponent.ctorParameters = function () { return [
        { type: Renderer2, },
        { type: HiNGConfig, },
    ]; };
    CarouselComponent.propDecorators = {
        "activeSlide": [{ type: Input },],
        "interval": [{ type: Input },],
        "animate": [{ type: Input },],
        "activeSlideChange": [{ type: Output },],
        "slides": [{ type: ContentChildren, args: [SlideDirective,] },],
        "slideItems": [{ type: ViewChildren, args: ['slideItem',] },],
        "selectPrevSlide": [{ type: HostListener, args: ['keydown.arrowLeft', ['$event'],] },],
        "selectNextSlide": [{ type: HostListener, args: ['keydown.arrowRight', ['$event'],] },],
        "pauseInterval": [{ type: HostListener, args: ['mouseenter', [],] },],
        "startInterval": [{ type: HostListener, args: ['mouseleave', [],] },],
    };
    return CarouselComponent;
}());
export { CarouselComponent };
